Name:          qoauth
Summary:       Qt-based C++ library for OAuth authorization scheme
Group:         Graphical desktop/KDE
Version:       2.0.1
Release:       %mkrel 2
License:       LGPLv2+
URL:           http://github.com/ayoy/qoauth
Source0:       http://files.ayoy.net/qoauth/release/%{version}/src/%{name}-%{version}-src.tar.xz
Patch0:        qoauth-2.0.1-Qt5-port.patch
BuildRequires: qt4-devel
BuildRequires: doxygen
BuildRequires: %{_lib}qca2-devel

BuildRequires: %{_lib}qt5core-devel
BuildRequires: %{_lib}qt5network-devel
BuildRequires: %{_lib}qt5test-devel
BuildRequires: %{_lib}qca2-qt5-devel

%description 
QOAuth is an attempt to support interaction with OAuth-powered network 
services in a Qt way, i.e. simply, clearly and efficiently. It gives 
the application developer no more than 4 methods, namely:

* requestToken() to obtain an unauthorized Request Token,
* accessToken() to exchange Request Token for the Access Token,
* createParametersString() to construct a request according to OAuth
  authorization scheme,
* inlineParemeters() - to construct a query string basing on given 
  parameters (provided only for convenience).

#-----------------------------------------------------------------------------   
%define qoauth_major 1
%define libqoauth %mklibname qoauth %{qoauth_major}

%package -n    %{libqoauth}
Summary:       %{name} Qt4 core library
Group:         System/Libraries
Requires:      qca2
Obsoletes:	   qoauth
Provides:	   qoauth = %version-%release

%description -n %{libqoauth}
%{name} Qt4 core library.

%files -n %{libqoauth}
%{_qt4_libdir}/libqoauth.so.%{qoauth_major}*

#-----------------------------------------------------------------------------

%define develname %mklibname qoauth -d

%package -n    %{develname}
Summary:       Qt4 Devel stuff for %{name}
Group:         Development/Libraries
Requires:      %{libqoauth} = %{version}-%{release}
Provides:      qoauth-devel = %{version}-%{release}
Provides:      libqoauth-devel = %{version}-%{release}
Obsoletes:     qoauth-devel

%description -n %{develname}
This package contains Qt4 header files needed if you wish to build
applications based on %{name}.

%files -n %{develname}
%doc qt4/doc/html qt4/doc/examples
%{_qt4_includedir}/QtOAuth
%{_qt4_libdir}/libqoauth.prl
%{_qt4_libdir}/libqoauth.so
%{_qt4_libdir}/pkgconfig/qoauth.pc
%{qt4dir}/mkspecs/features/oauth.prf

#----------------------------------------------------------------------------- 
### Qt5 ###

%define qoauth_qt5_major 2
%define libqoauth_qt5 %mklibname qoauth 5 %{qoauth_qt5_major}

%package -n    %{libqoauth_qt5}
Summary:       %{name} Qt5 core library
Group:         System/Libraries
Requires:      qca2-qt5

%description -n %{libqoauth_qt5}
%{name} Qt5 core library.

%files -n %{libqoauth_qt5}
%{_qt5_libdir}/libqoauth5.so.%{qoauth_qt5_major}*

#-----------------------------------------------------------------------------

%define develname_qt5 %mklibname qoauth-qt5 -d

%package -n    %{develname_qt5}
Summary:       Qt5 Devel stuff for %{name}
Group:         Development/Libraries
Requires:      %{libqoauth_qt5} = %{version}-%{release}
Provides:      qoauth-qt5-devel = %{version}-%{release}
Provides:      libqoauth-qt5-devel = %{version}-%{release}

%description -n %{develname_qt5}
This package contains Qt5 header files needed if you wish to build
applications based on %{name}.

%files -n %{develname_qt5}
%doc qt5/doc/html qt5/doc/examples
%{_qt5_includedir}/QtOAuth/
%{_qt5_libdir}/libqoauth5.prl
%{_qt5_libdir}/libqoauth5.so
%{_qt5_libdir}/pkgconfig/qoauth-qt5.pc
%{_qt5_prefix}/mkspecs/features/oauth.prf

### End Qt5 ###
#-----------------------------------------------------------------------------

%prep
%setup -q -c
mv %{name}-%{version}-src qt4
cp -a qt4 qt5

### Prepare Qt4 ###
pushd qt4
sed -i -e 's\/lib\/%{_lib}\g' src/pcfile.sh
popd
### Prepare Qt5 ###
pushd qt5
%patch0 -p1
sed -i -e 's\/lib\/%{_lib}\g' src/pcfile.sh
popd

%build
### Qt4 build ###
pushd qt4
%qmake_qt4
%make

doxygen Doxyfile
popd

### Qt5 build ###
pushd qt5
%qmake_qt5
%make

doxygen Doxyfile
popd

%install
rm -rf %buildroot
%make_install -C qt4 INSTALL_ROOT=%{buildroot}
%make_install -C qt5 INSTALL_ROOT=%{buildroot}

# fix the time stamp
pushd qt4
for file in doc/html/*; do
     touch -r Doxyfile $file
done
popd

pushd qt5
for file in doc/html/*; do
     touch -r Doxyfile $file
done
popd


%changelog
* Sun Mar 26 2017 adrianomorselli <adrianomorselli> 2.0.1-2uplos2017
- rebuild for 2017
